==> clitui-0.1.1.tar.gz: clitui-0.1.1/README.md <==
# CLITUI


## Installing
```
pip install clitui
```

module v 0.1.0

keyboard support only on:
Mac
Linux

TUI is a module for making custom CLI/Console App's with python


## Terminal suport
[x] Mac
[X] Linux
[ ] Windows CMD

## Features
* Label's
* Keybindings
* Everything so far is in python

### Reason For Using this module.
* Game
    * Text based games (aka the real reason that lead me to make this module)
    * Tetras
    * Packman
    * Hangman
    * Block Break

* Tools
    * Hacking tools
    * Development tools

Really there is is not reason, I only made this to have something to do and 
build my knowledge in python.  I will though make a few games with it after I get this 
module working. Lots and lots of work ahead still.


### Screen Shot
This is what I have so far, not much but it's a work in progress.

To get this example do
```
clitui
```
in terminal and watch it rain!

![](https://user-images.githubusercontent.com/43012445/67812482-4bb45700-fa6d-11e9-8ce9-504af8e0a6d7.png)

You can place Labels
It's not perfect but it works pretty well.

![](https://user-images.githubusercontent.com/43012445/60067666-208db580-96d1-11e9-85c4-b04c7941b694.gif)

Placement of objects on screen and move it with key bindings.

![Movement](https://user-images.githubusercontent.com/43012445/59881361-007a9100-9375-11e9-942a-848c0c88d926.gif)

Automatic detection of terminal size, not yet dynamically made. Only finds
size of terminal when being created so if you resize the terminal the program will not 
know....yet

![FullScreen](https://user-images.githubusercontent.com/43012445/59881653-bcd45700-9375-11e9-91d2-c6bd90662475.gif)`


### TODO:

* add keyboard support for Windows
* Refactor existing code.

==> clitui-0.2.0.tar.gz: clitui-0.2.0/README.md <==
# CLITUI


## Installing
```
pip install clitui
```

module v 0.1.0

keyboard support only on:
Mac
Linux

TUI is a module for making custom CLI/Console App's with python


## Terminal suport
- [x] Mac
- [X] Linux
- [ ] Windows CMD

## Features
* Label's
* Keybindings
* Everything so far is in python

### Reason For Using this module.
* Game
    * Text based games (aka the real reason that lead me to make this module)
    * Tetras
    * Packman
    * Hangman
    * Block Break

* Tools
    * Hacking tools
    * Development tools

Really there is is not reason, I only made this to have something to do and 
build my knowledge in python.  I will though make a few games with it after I get this 
module working. Lots and lots of work ahead still.


### Screen Shot
This is what I have so far, not much but it's a work in progress.

To get this example do
```
clitui matrix
```
in terminal and watch it rain!

![matrix_rain2](https://user-images.githubusercontent.com/43012445/67877665-fbd69e00-fb07-11e9-8093-794dd2f8a66f.gif)
```
clitui matrix j
```
![jap_matrix_rain2](https://user-images.githubusercontent.com/43012445/67978841-0026b800-fbe9-11e9-96a4-d5d6f558b50a.gif)

You can place Labels
It's not perfect but it works pretty well.
Not stable

![](https://user-images.githubusercontent.com/43012445/60067666-208db580-96d1-11e9-85c4-b04c7941b694.gif)

Placement of objects on screen and move it with key bindings.
Not stable

![Movement](https://user-images.githubusercontent.com/43012445/59881361-007a9100-9375-11e9-942a-848c0c88d926.gif)

Automatic detection of terminal size, not yet dynamically made. Only finds
size of terminal when being created so if you resize the terminal the program will not.

![FullScreen](https://user-images.githubusercontent.com/43012445/59881653-bcd45700-9375-11e9-91d2-c6bd90662475.gif)`


### TODO:
* 
* add keyboard support for Windows
* Refactor existing code.
